/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

syntax = "proto2";
package android.service.battery;

option java_multiple_files = true;
option java_outer_classname = "BatteryServiceProto";

import "frameworks/base/core/proto/android/privacy.proto";
import "frameworks/proto_logging/stats/enums/os/enums.proto";

message BatteryServiceDumpProto {
    option (android.msg_privacy).dest = DEST_AUTOMATIC;

    // If true: UPDATES STOPPED -- use 'reset' to restart
    optional bool are_updates_stopped = 1;
    // Plugged status of power sources
    optional android.os.BatteryPluggedStateEnum plugged = 2;
    // Max current in microamperes. This may be 0 if the device's kernel drivers
    // don't support it.
    optional int32 max_charging_current = 3;
    // Max voltage. This may be 0 if the device's kernel drivers don't support
    // it.
    optional int32 max_charging_voltage = 4;
    // Battery capacity in microampere-hours
    optional int32 charge_counter = 5;
    // Charging status
    optional android.os.BatteryStatusEnum status = 6;
    // Battery health
    optional android.os.BatteryHealthEnum health = 7;
    // True if the battery is present
    optional bool is_present = 8;
    // Charge level, from 0 through "scale" inclusive
    optional int32 level = 9;
    // The maximum value for the charge level
    optional int32 scale = 10;
    // Battery voltage in millivolts
    optional int32 voltage = 11;
    // Battery temperature in tenths of a degree Centigrade
    optional int32 temperature = 12;
    // The type of battery installed, e.g. "Li-ion"
    optional string technology = 13;
}
